#!/usr/bin/env python

from yattag import Doc, indent
import sys
import lxml.etree
from minibelt import get

ORIGINAL = "backup-messages.xml"
OUTPUT = "out.xml"

def cleanorigin(fpath):
    with open(fpath) as f:
        data = f.read()
    toreplace = (('&', '&amp;'), ('<', '&lt;'), ('>', '&gt;'), ('"', '&quot;'), ("'", '&apos;'))

    text = data
    newtext = []
    while '<body>' in text:
        fidx = text.find("<body>")
        eidx = text.find("</body>")
        body = text[fidx+6:eidx]
        for (old, new) in toreplace:
            body = body.replace(old, new)
        body = '<body>' + body + '</body>'
        newtext.append(text[:fidx])
        newtext.append(body)
        text = text[eidx+7:]
    newtext.append(text)

    originxml = '<root>' + ''.join(newtext) + '</root>'
    return originxml

def writexml(data, output):
    root = lxml.etree.fromstring(data)

    messages = []

    for message in root.xpath("./message"):
        body = get(message.xpath("./body/text()"), 0, default='')
        delivery = get(message.xpath("./delivery/text()"), 0, default='')
        read = get(message.xpath("./read/text()"), 0, default='')
        receiver = get(message.xpath("./receiver/text()"), 0, default='')
        sender = get(message.xpath("./sender/text()"), 0, default='')
        timestamp = get(message.xpath("./timestamp/text()"), 0, default='')

        args = {}

        args['protocol'] = 0
        if delivery == 'received':
            args['address'] = sender
            args['type'] = 1
        elif delivery == 'sent':
            args['address'] = receiver
            args['type'] = 2
        else:
            print('Bad delivery: ', delivery, file=sys.stderr)
            continue

        args['date'] = timestamp
        args['subject'] = 'null'
        args['body'] = body
        args['toa'] = 'null'
        args['sc_toa'] = 'null'
        args['service_center'] = 'null'

        if read == 'true':
            args['read'] = 1
        elif read == 'false':
            args['read'] = 0
        else:
            print("Bad read :", read, file=sys.stderr)
            continue

        args['status'] = -1
        messages.append(args)


    doc, tag, text = Doc().tagtext()
    header = """\
    <?xml version='1.0' encoding='UTF-8' standalone='yes' ?>
    <?xml-stylesheet type="text/xsl" href="sms.xsl"?>\
    """

    with doc.tag("smses", count=len(messages)):
        for message in messages:
            doc.stag("sms", **message)

    with open(output, "w") as f:
        print(header, file=f)
        print(indent(doc.getvalue()), file=f)

data = cleanorigin(ORIGINAL)
writexml(data, OUTPUT)
